%define _exclude_files_from_autoprov %{python3_sitearch}/.*\\.so

Name:           recoll
Version:        1.37.5
Release:        %mkrel 1
Summary:        Desktop full text search tool with a Qt GUI
Group:          Databases
License:        GPLv2
URL:            https://www.recoll.org
Source0:        https://www.recoll.org/%{name}-%{version}.tar.gz
Patch0:         recoll-1.34.0-py3-only.patch
BuildRequires:  pkgconfig(xapian-core)
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5WebEngineWidgets)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  bison-devel-static
BuildRequires:  aspell-devel
BuildRequires:  chmlib-devel

Requires:       aspell
Requires:       xapian

%description
Recoll is a personal full text search package for Linux, FreeBSD and
other Unix systems. It is based on a very strong backend (Xapian), for
which it provides an easy to use, feature-rich, administration
interface.

#------------------------------------------------------

%package -n %{name}-extra
Summary:        Recoll extra indexing packages
Group:          File tools
Requires:       %{name} >= %{version}-%{release}
BuildArch:      noarch
Recommends:     antiword
Recommends:     aspell-en
Recommends:     catdoc
Recommends:     djvulibre
Recommends:     libwpd-tools
Recommends:     python3dist(mutagen)
Recommends:     perl-Image-ExifTool
Recommends:     poppler
Recommends:     pstotext
Recommends:     python3
Recommends:     python3dist(pylzma)
Recommends:     python3dist(rarfile)
Recommends:     texlive
Recommends:     unrar
Recommends:     unrtf
Recommends:     unzip
Recommends:     xsltproc

%description -n %{name}-extra
This package contains a list of packages' suggestions
for indexing various file types by recoll:

* antiword for MS Word files.
* catdoc for MS Excel and PowerPoint files.
* unrtf for RTF files.
* djvulibre (djvutxt djvused) for djvu files.
* libwpd-tools for Wordperfect files.
* Midi karaoke files need Python and the Midi module
* mutagen for all audio file types.
* perl-Image-ExifTool to extract tag informations:
    This is only of interest if you store personal tags
    or textual descriptions inside the image files.
* Zip archives need Python (and the standard zipfile module).
* Rar archives need Python, the rarfile Python module and the unrar utility.
* 7zip archives (needs Python and the pylzma module)
* Poppler(pdftotext) for PDF files.
* pstotext for Postscript files.
* texlive :
    detex for TeX files.
    dvips for div files.
* unzip and xsltproc for LibreOffice files.
* xsltproc for MS Open XML (docx).

#--------------------------------------------------------

%package -n python3-%{name}
Summary:        Python 3 extension module for recoll
Group:          Development/Python

BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
Requires:       python3
Requires:       %{name} >= %{version}-%{release}

%description -n python3-%{name}
Recoll Python 3 programming interface, for searching and indexing.

#--------------------------------------------------------

%define major   %{version}
%define libname %mklibname %{name} %{major}

%package -n %{libname}
Summary:        Libraries for Recoll applications
Group:          System/Libraries

%description -n %{libname}
Shared libraries required to run Recoll applications.

#--------------------------------------------------------

%define devname %mklibname %{name} -d

%package -n %{devname}
Summary:        Libraries and header files to develop Recoll enabled applications
Group:          Development/KDE and Qt
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
Libraries and header files required to develop Recoll enabled
applications.

#--------------------------------------------------------

%package -n kio-%{name}
Summary:        KIO slave for %{name}
Group:          Graphical desktop/KDE

BuildRequires:  kf5-rpm-macros
BuildRequires:  cmake(KF5KIO)

Requires:       %{name} >= %{version}-%{release}
Requires:       kf5-plasma-framework

%description -n kio-%{name}
KIO slave for %{name}. Enables to perform queries and extract
results in Konqueror and Dolphin.

#-------------------------------------------------------

%package        krunner
Summary:        KRunner support for %{name}
Group:          Graphical desktop/KDE

BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5Runner)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Notifications)

Requires:       %{name} >= %{version}-%{release}

%description   krunner
The recoll KRunner plugin adds Recoll search results to
KRunner output.

#-------------------------------------------------------

%package -n %{name}-full
Summary:        Full Recoll installation
Group:          Office/Utilities
BuildArch:      noarch

Requires:       %{name} >= %{version}-%{release}
Requires:       %{name}-extra >= %{version}-%{release}
Requires:       python3-%{name} >= %{version}-%{release}
Requires:       kio-%{name} >= %{version}-%{release}
Requires:       recoll-krunner >= %{version}-%{release}

%description -n %{name}-full
This packages provides the complete recoll installation:

* recoll: The main application
* recoll-extra: Recoll extra indexing packages
* python-recol: Python extension module for recoll
* kio-recoll: KDE KIO slave for recoll
* plasma-runner-recoll: KDE krunner plugin for recoll

#------------------------------------------------------

%prep
%autosetup -p1

%build
%configure \
    QMAKE=%{_qt5_bindir}/qmake \
    --without-fam \
    --disable-webkit \
    --enable-recollq \
    --enable-publiclib \
    --enable-webengine \
    --disable-python-aspell
%make_build

%install
%make_install

# Remove library to avoid dynamic linkinkg
# when compiling kio recoll.
# The linking made kio recoll non functional
%__rm -f lib/librecoll.so*

pushd kde/kioslave/kio_recoll
%cmake -DRECOLL_PUBLIC_LIB=1
%cmake_build
%cmake_install
popd

# krunner_recoll
pushd kde/krunner
%cmake -DRECOLL_PUBLIC_LIB=1
%cmake_build
%cmake_install
popd

# Add translations tags
(cd %{buildroot} && find . -name '*.qm') | sed -e 's|^.||' | sed -e \
    's:\(.*/translations/\)\([a-z]\+_\)\([a-zA-Z_]\+\)\(\.qm\):%lang(\3) \1\2\3\4:' \
        >> %{name}.lang

%files -f %{name}.lang
%doc README
%{_bindir}/*
%{_datadir}/applications/recoll-searchgui.desktop
%{_datadir}/pixmaps/recoll.png
%{_datadir}/%{name}/doc/
%{_datadir}/%{name}/examples/
%{_datadir}/%{name}/filters/
%{_datadir}/%{name}/images/
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations
%{_iconsdir}/hicolor/48x48/apps/recoll.png
%{_mandir}/man1/recoll*
%{_mandir}/man5/recoll*
%{_metainfodir}/recoll.appdata.xml
%{_unitdir}/recollindex@.service
%{_userunitdir}/recollindex.service

#-------------------------------------------------------
%files -n %{name}-extra
#none

#-------------------------------------------------------
%files -n python3-%{name}
%{python3_sitearch}/recoll/
%{python3_sitearch}/recollchm/
%{python3_sitearch}/Recoll-%version-py%{python3_version}.egg-info/
%{python3_sitearch}/recollchm-*-py%{python3_version}.egg-info

#-------------------------------------------------------
%files -n %{libname}
%{_libdir}/librecoll-%{version}.so

#-------------------------------------------------------
%files -n %{devname}
%{_includedir}/recoll/
%{_libdir}/librecoll.so

#-------------------------------------------------------
%files -n kio-%{name}
%dir %{_datadir}/kio_recoll
%{_qt5_plugindir}/kf5/kio/kio_recoll.so
%{_datadir}/kio_recoll/help.html
%{_datadir}/kio_recoll/welcome.html

#-------------------------------------------------------
%files krunner
%{_qt5_plugindir}/kf5/krunner/runner_recoll.so

#-------------------------------------------------------
%files -n %{name}-full
# none


%changelog
* Thu Jun 20 2024 daviddavid <daviddavid> 1.37.5-1.mga10
+ Revision: 2075705
- new version: 1.37.5
- add missing runtime dependency on aspell (mga#32921)

* Wed Mar 13 2024 daviddavid <daviddavid> 1.37.4-1.mga10
+ Revision: 2049764
- new version: 1.37.4

* Tue Dec 19 2023 daviddavid <daviddavid> 1.36.2-2.mga10
+ Revision: 2019239
- fix dependencies

* Thu Dec 14 2023 daviddavid <daviddavid> 1.36.2-1.mga10
+ Revision: 2018114
- new version: 1.36.2
- build and package recoll-krunner
- enable now shared publiclib
- new version: 1.36.1

* Sun Jan 29 2023 daviddavid <daviddavid> 1.34.2-1.mga9
+ Revision: 1936884
- new version: 1.34.2

* Sun Jan 15 2023 daviddavid <daviddavid> 1.34.0-1.mga9
+ Revision: 1933345
- new version: 1.34.0

* Sun Sep 25 2022 neoclust <neoclust> 1.32.7-1.mga9
+ Revision: 1892238
- New version 1.32.7
+ tv <tv>
- Rebuild for python-3.10
+ daviddavid <daviddavid>
- new version: 1.31.0

* Sun Apr 18 2021 daviddavid <daviddavid> 1.30.1-1.mga9
+ Revision: 1716432
- new version: 1.30.1
- remove merged upstream patch

* Fri Apr 09 2021 daviddavid <daviddavid> 1.30.0-1.mga9
+ Revision: 1714318
- new version: 1.30.0

* Sun Mar 28 2021 daviddavid <daviddavid> 1.29.2-1.mga9
+ Revision: 1711502
- new version: 1.29.2

* Sat Mar 20 2021 daviddavid <daviddavid> 1.28.6-2.mga9
+ Revision: 1705393
- rebuild for python 3.9

* Tue Mar 02 2021 daviddavid <daviddavid> 1.28.6-1.mga9
+ Revision: 1695822
- new version: 1.28.6

* Sat Dec 19 2020 daviddavid <daviddavid> 1.27.12-1.mga8
+ Revision: 1661188
- new version: 1.27.12

* Thu Dec 17 2020 umeabot <umeabot> 1.27.11-2.mga8
+ Revision: 1659724
- Rebuild for new Qt5

* Tue Nov 17 2020 daviddavid <daviddavid> 1.27.11-1.mga8
+ Revision: 1646778
- new version: 1.27.11

* Thu Oct 22 2020 daviddavid <daviddavid> 1.27.9-1.mga8
+ Revision: 1638127
- new version: 1.27.9

* Tue Jun 30 2020 daviddavid <daviddavid> 1.27.3-1.mga8
+ Revision: 1600721
- new version: 1.27.3

* Thu May 28 2020 daviddavid <daviddavid> 1.27.2-1.mga8
+ Revision: 1588311
- new version: 1.27.2

* Sun May 10 2020 daviddavid <daviddavid> 1.27.0-1.mga8
+ Revision: 1582467
- new version: 1.27.0

* Sun Apr 05 2020 daviddavid <daviddavid> 1.26.7-1.mga8
+ Revision: 1564881
- new version: 1.26.7

* Tue Mar 31 2020 daviddavid <daviddavid> 1.26.6-1.mga8
+ Revision: 1562687
- new version: 1.26.6

* Mon Mar 02 2020 daviddavid <daviddavid> 1.26.5-1.mga8
+ Revision: 1553020
- new version: 1.26.5

* Wed Feb 19 2020 umeabot <umeabot> 1.26.4-2.mga8
+ Revision: 1544549
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 daviddavid <daviddavid> 1.26.4-1.mga8
+ Revision: 1483259
- new version: 1.26.4
+ wally <wally>
- replace deprecated %%configure2_5x
- build with new cmake macros

* Mon Dec 02 2019 daviddavid <daviddavid> 1.26.3-1.mga8
+ Revision: 1464061
- new version: 1.26.3

* Mon Nov 04 2019 daviddavid <daviddavid> 1.26.1-1.mga8
+ Revision: 1457502
- new version: 1.26.1

* Thu Oct 17 2019 daviddavid <daviddavid> 1.26.0-1.mga8
+ Revision: 1454220
- new version: 1.26.0

* Sun Oct 13 2019 daviddavid <daviddavid> 1.25.23-1.mga8
+ Revision: 1452669
- new version: 1.25.23

* Thu Sep 26 2019 daviddavid <daviddavid> 1.25.22-2.mga8
+ Revision: 1446203
- rebuild for python3.8

* Fri Sep 06 2019 daviddavid <daviddavid> 1.25.22-1.mga8
+ Revision: 1437747
- new version: 1.25.22
- drop python2 support

* Tue Jul 02 2019 daviddavid <daviddavid> 1.25.19-1.mga8
+ Revision: 1417795
- new version: 1.25.19

* Sat Apr 13 2019 daviddavid <daviddavid> 1.25.13-1.mga7
+ Revision: 1389782
- new version: 1.25.13

* Mon Apr 01 2019 daviddavid <daviddavid> 1.25.11-1.mga7
+ Revision: 1384724
- new version: 1.25.11

* Mon Apr 01 2019 umeabot <umeabot> 1.25.5-2.mga7
+ Revision: 1384675
- Qt5 Rebuild

* Thu Mar 14 2019 daviddavid <daviddavid> 1.25.5-1.mga7
+ Revision: 1376109
- new version: 1.25.5

* Fri Mar 01 2019 daviddavid <daviddavid> 1.25.4-1.mga7
+ Revision: 1370639
- new version: 1.25.4

* Wed Feb 06 2019 daviddavid <daviddavid> 1.24.5-1.mga7
+ Revision: 1363638
- new version: 1.24.5

* Mon Nov 19 2018 daviddavid <daviddavid> 1.24.3-2.mga7
+ Revision: 1331852
- new version: 1.24.3
- remove merged upstream patch

* Sun Sep 23 2018 umeabot <umeabot> 1.24.1-3.mga7
+ Revision: 1300799
- Mageia 7 Mass Rebuild

* Sat Jun 02 2018 daviddavid <daviddavid> 1.24.1-2.mga7
+ Revision: 1233560
- add patch to fix build with new Qt5 >= 5.11.0 stack

* Tue May 22 2018 daviddavid <daviddavid> 1.24.1-1.mga7
+ Revision: 1231389
- new version: 1.24.1

* Tue Apr 17 2018 daviddavid <daviddavid> 1.23.7-3.mga7
+ Revision: 1219584
- rebuild for new xapian 1.4.5

* Tue Apr 10 2018 dglent <dglent> 1.23.7-2.mga7
+ Revision: 1217136
- Add python-libxslt in recoll-extra mga#22885

* Sat Feb 17 2018 daviddavid <daviddavid> 1.23.7-1.mga7
+ Revision: 1202052
- new version: 1.23.7
- rename python-recoll to python2-recoll
- use new python provides
- fix owner of data dir

* Fri Nov 04 2016 ghibo <ghibo> 1.22.3-2.mga6
+ Revision: 1065233
- Update to release 1.22.3.

* Fri May 06 2016 dglent <dglent> 1.21.6-1.mga6
+ Revision: 1009687
- Version 1.21.6
- KF5 for kio slave
+ daviddavid <daviddavid>
- use new python macros

* Thu Jan 21 2016 dglent <dglent> 1.21.4-1.mga6
+ Revision: 926186
- Version 1.21.4
- Add python-pylzma in recommends mga#17546

* Sun Nov 08 2015 dglent <dglent> 1.21.3-1.mga6
+ Revision: 898881
- Version 1.21.3

* Thu Aug 27 2015 cjw <cjw> 1.20.6-3.mga6
+ Revision: 870117
- rebuild with gcc 5

* Thu Jun 25 2015 dglent <dglent> 1.20.6-2.mga6
+ Revision: 842990
- Add BR Qt5WebKitWidgets
  Force Qt5 build

* Mon Jun 22 2015 dglent <dglent> 1.20.6-1.mga6
+ Revision: 839919
- Version 1.20.6
  Qt5 build

* Wed Oct 15 2014 umeabot <umeabot> 1.19.14p2-4.mga5
+ Revision: 750066
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.19.14p2-3.mga5
+ Revision: 730088
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.19.14p2-2.mga5
+ Revision: 688633
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Sat Jul 26 2014 dglent <dglent> 1.19.14p2-1.mga5
+ Revision: 656590
- New version 1.19.14p2
+ pterjan <pterjan>
- Rebuild for new Python

* Sun May 11 2014 dglent <dglent> 1.19.13-1.mga5
+ Revision: 621947
- New version 1.19.13

* Mon Apr 21 2014 dglent <dglent> 1.19.12p1-1.mga5
+ Revision: 617217
- New version 1.19.12p1
- Find translations and add tags with sed

* Fri Dec 20 2013 dglent <dglent> 1.19.11p1-2.mga4
+ Revision: 559046
- Prevent linking lib with kio-recoll (brakes the application)

* Wed Dec 18 2013 dglent <dglent> 1.19.11p1-1.mga4
+ Revision: 558415
- Fix typos in descriptions
- Exclude library from provides
- Exclude library from requires
- Exclude python library from provides
- Add Requires qt4-common
- Add BR zlib-devel
- Add package recoll-extra
- Add package python-recoll
- Add package recoll-full
- Add lang tags
- Remove surplus in %%setup
- New version 1.19.11p1
- Revert no needed now changes for kio-recoll and library linking (rev#552031)
- Cosmetic change in snippets separators
- Convert tabs to spaces
- Fix some grammar typos in descriptions
- Add %%dir in files
- Add %%doc in kio-recoll
- Fix not working of kio-recoll since v1.19
- Cosmetic chnages in SPEC
- New version 1.19.9
- New version 1.19.9
- New version 1.19.5
- Add requires in kio package
- Remove copy of gpl license
- New version 1.19.4
- Add docs in spec
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 1.18.1-2.mga3
+ Revision: 380265
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Nov 05 2012 dglent <dglent> 1.18.1-1.mga3
+ Revision: 314471
- New version 1.18.1

* Sun Sep 30 2012 dglent <dglent> 1.17.3-2.mga3
+ Revision: 300817
- Fix kio slave package non build
- Add kio slave package
- Spec cleanup
- Change license to GPLv2

* Sat Jun 02 2012 fwang <fwang> 1.17.3-1.mga3
+ Revision: 253265
- disable python module
- br python
- add br
- new version 1.17.3

* Fri Dec 30 2011 supp <supp> 1.16.2-1.mga2
+ Revision: 189028
- update to 1.16.2

* Fri Oct 07 2011 fwang <fwang> 1.16.1-1.mga2
+ Revision: 152724
- new version 1.16.1

* Wed Sep 28 2011 supp <supp> 1.16.0-1.mga2
+ Revision: 149922
- fix package group
- imported package recoll

